CREATE SCHEMA Strassennetz

-- Historie:
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Strasse, Netzknoten, Nullpunkt, Abschnitt_oder_Ast
-- und Verwaltungsbezirk
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Strassenklasse (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenklasse VALUES ('A','Bundesautobahn')
INSERT INTO Strassenklasse VALUES ('B','Bundesstrae')
INSERT INTO Strassenklasse VALUES ('L','Landesstrae')
INSERT INTO Strassenklasse VALUES ('S','Staatsstrae')
INSERT INTO Strassenklasse VALUES ('K','Kreisstrae')
INSERT INTO Strassenklasse VALUES ('G','Gemeindestrae')

CREATE TABLE Strasse (
   Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strasse_ID) REFERENCES Strasse_abstrakt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Strassenklasse
      CHAR(1) NOT NULL REFERENCES Strassenklasse,
   Strassennummer
      INTEGER NOT NULL, -- Strassennummer
   CHECK ( ( Strassennummer > 0 ) AND ( Strassennummer <= 9999 ) ),
   Zusatzbuchstabe
      CHAR(1), -- Zusatzbuchstabe
   CHECK ( ( Zusatzbuchstabe >= 'A' ) AND ( Zusatzbuchstabe <= 'Z' ) )
)

CREATE TABLE Strasse__hat_Strassenknoten (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Strasse__hat_AoA (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Strasse__hat_BAB_Knotennummer (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Strasse__in_Verwaltungsbezirk (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Verwaltungsbezirk_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Strasse__enthaelt_Block (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Strasse_abstrakt (
   Strasse_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Art_Strasse_abstrakt
)

CREATE TABLE Art_Strasse_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Strasse_abstrakt VALUES (1,'Strasse')
INSERT INTO Art_Strasse_abstrakt VALUES (2,'Strasse_Symbol')

CREATE TABLE Strasse_Symbol (
   Strasse_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_Symbol_ID) REFERENCES Strasse_abstrakt,
   Kennung
      VARCHAR(7) NOT NULL
)

CREATE TABLE Verlaufskennzeichen (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verlaufskennzeichen VALUES (1,'Anfang Strae')
INSERT INTO Verlaufskennzeichen VALUES (2,'Ende Strae')
INSERT INTO Verlaufskennzeichen VALUES (3,'Anfang Seitenarm')
INSERT INTO Verlaufskennzeichen VALUES (4,'Ende Seitenarm')
INSERT INTO Verlaufskennzeichen VALUES (5,'Anfang Unterbrechung')
INSERT INTO Verlaufskennzeichen VALUES (6,'Ende Unterbrechung')
INSERT INTO Verlaufskennzeichen VALUES (7,'Anfang getr. verl. Fahrbahn')
INSERT INTO Verlaufskennzeichen VALUES (8,'Ende getr. verl. Fahrbahn')
INSERT INTO Verlaufskennzeichen VALUES (9,'Wiederholung')

CREATE TABLE Strasse_Netzknoten (
   Strasse_Netzknoten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_Netzknoten_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Verlaufskennzeichen
      INTEGER REFERENCES Verlaufskennzeichen
)

CREATE TABLE Strasse_NK__hat_Netzknoten (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Strasse_NK__hat_Vorgaenger (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Strasse_Netzknoten_2
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Strasse_Netzknoten__von_Strasse (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE Knotenart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenart VALUES (1,'plangleich (hhengleich)')
INSERT INTO Knotenart VALUES (2,'planfrei (hhenungleich)')
INSERT INTO Knotenart VALUES (3,'teilplanfrei')
INSERT INTO Knotenart VALUES (0,'fiktiver Netzknoten')

CREATE TABLE Knotenpunktsform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsform VALUES (01,'Einmndung oder Kreuzung von ' ||
 '2-streifigen Straen')
INSERT INTO Knotenpunktsform VALUES (02,'Einmndung oder Kreuzung von ' ||
 '2-bahnigen mit 2-streifigen Straen in der Regel mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (03,'Einmndung oder Kreuzung von zwei ' ||
 '2-bahnigen Straen mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (04,'planfreie Kreuzung von ' ||
 '2-streifigen oder 2-bahnigen Straen')
INSERT INTO Knotenpunktsform VALUES (05,'Kreuzung 2-streifiger Straen ' ||
 'als Versatz')
INSERT INTO Knotenpunktsform VALUES (06,'Aufgeweitete Einmndung oder ' ||
 'Kreuzung mit mindestens einer 2-bahnigen Strae')
INSERT INTO Knotenpunktsform VALUES (07,'Kreisverkehrsplatz, d < 30 m')
INSERT INTO Knotenpunktsform VALUES (08,'Kreisverkehr, d > 30 m')

CREATE TABLE Knotenpunktsystem (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsystem VALUES (01,'Trompete')
INSERT INTO Knotenpunktsystem VALUES (02,'Birne')
INSERT INTO Knotenpunktsystem VALUES (03,'Dreieck mit 3 zweigeschossigen ' ||
 'Bauwerken')
INSERT INTO Knotenpunktsystem VALUES (04,'Dreieck mit 1 dreigeschossigen ' ||
 'Bauwerk')
INSERT INTO Knotenpunktsystem VALUES (05,'Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (06,'Kleeblatt, abgewandelt mit ' ||
 'halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (07,'Kleeblatt, abgewandelt mit ' ||
 'zgiger halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (08,'halbes Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (09,'halbes Kleeblatt, asymmetrisch ' ||
 'mit auenliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (10,'halbes Kleeblatt, asymmetrisch ' ||
 'mit innen- und hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (11,'halbes Kleeblatt, asymmetrisch ' ||
 'mit innen- und nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (12,'halbes Kleeblatt, symmetrisch')
INSERT INTO Knotenpunktsystem VALUES (13,'Raute mit innen- und ' ||
 'hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (14,'Raute mit innen- und ' ||
 'nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (15,'Raute mit aufgeweiteter Kreuzung')
INSERT INTO Knotenpunktsystem VALUES (16,'Raute mit auenliegenden ' ||
 'Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (17,'Sondersystem')

CREATE TABLE Netzknoten (
   Netzknoten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Netzknoten_abstrakt,
   Netzknoten_ext
      CHAR(7),
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Numerierungsbezirk
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( Numerierungsbezirk >= 1 ) AND ( Numerierungsbezirk <= 9999 ) ),
   Nummer
      INTEGER NOT NULL, -- lfd_NK_Nummer
   CHECK ( ( Nummer >= 1 ) AND ( Nummer <= 999 ) ),
   Knotenart
      INTEGER REFERENCES Knotenart,
   Knotenname
      VARCHAR(30),
   Knotenpunktsform
      INTEGER REFERENCES Knotenpunktsform,
   Knotenpunktsystem
      INTEGER REFERENCES Knotenpunktsystem
)

CREATE TABLE NK__hat_BAB_Knotennummer (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Netzknoten__hat_Nullpunkt (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Netzknoten__in_Strassenknoten (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Netzknoten__Beginn_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__Ende_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__auf_Trasse (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Trasse
      INTEGER NOT NULL REFERENCES Entwurf.Trasse
)

CREATE TABLE Netzknoten_abstrakt (
   Netzknoten_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Art_Netzknoten_abstrakt
)

CREATE TABLE Art_Netzknoten_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(17) NOT NULL
)

INSERT INTO Art_Netzknoten_abstrakt VALUES (1,'Netzknoten')
INSERT INTO Art_Netzknoten_abstrakt VALUES (2,'Netzknoten_Symbol')

CREATE TABLE Netzknoten_Symbol (
   Netzknoten_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_Symbol_ID) REFERENCES Netzknoten_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE BAB_Knotennummer (
   BAB_Knotennummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (BAB_Knotennummer_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Knotennummer
      INTEGER NOT NULL,
   Buchstabe
      CHAR(1)
)

CREATE TABLE BAB_Knotennummer__auf_Strasse (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE BAB_Knotennummer__von_NK (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Stadium (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Stadium VALUES (00,'unter Verkehr')
INSERT INTO Stadium VALUES (11,'Neubau in Planung')
INSERT INTO Stadium VALUES (12,'Neubau in Ausfhrung')
INSERT INTO Stadium VALUES (20,'Erneuerung/Ersatzneubau in Planung')
INSERT INTO Stadium VALUES (21,'Erneuerung/Ersatzneubau in Ausfhrung')
INSERT INTO Stadium VALUES (30,'Instandsetzung in Planung')
INSERT INTO Stadium VALUES (31,'Instandsetzung in Ausfhrung')

CREATE TABLE Abschnitt_oder_Ast (
   Abschnitt_oder_Ast_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Abschnitt_oder_Ast_ext
      CHAR(16),
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast,
   Laenge
      REAL, -- Meter
   CHECK ( Laenge>=0 ),
   Stadium
      INTEGER REFERENCES Stadium,
   Streckenart
      INTEGER,
   Verkehrsfreigabe
      CHAR(10), -- Datum
   CHECK ( Verkehrsfreigabe LIKE '__.__.____' ),
   Abschnittsnummer
      INTEGER -- Abschnitt
)

CREATE TABLE Art_Abschnitt_oder_Ast (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(9) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast VALUES (1,'Abschnitt')
INSERT INTO Art_Abschnitt_oder_Ast VALUES (2,'Ast')

CREATE TABLE AoA__beginnt_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__endet_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__gehoert_zu_Strasse (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE AoA__hat_Teilabschnitt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL NOT NULL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL NOT NULL, -- Meter
   CHECK ( Station_2>=0 )
)

CREATE TABLE AoA__hat_Strassenpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 )
)

CREATE TABLE Abschnitt_oder_Ast_abstrakt (
   Abschnitt_oder_Ast_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Abschnitt_oder_Ast_abstr
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast_abstr
)

CREATE TABLE Art_Abschnitt_oder_Ast_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(25) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES (1,'Abschnitt')
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES (2,'Ast')
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES (3,'Abschnitt_oder_Ast_Symbol')

CREATE TABLE Abschnitt_oder_Ast_Symbol (
   Abschnitt_oder_Ast_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_Symbol_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Kennung
      VARCHAR(16) NOT NULL
)

CREATE TABLE Verkehrliche_Verknuepfung (
   Verkehrliche_Verknuepfung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrliche_Verknuepfung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE VV__von_Strassenelement (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE VV__nach_Strassenelement (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE VV__ueber_Nullpunkt (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Nullpunkt (
   Nullpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES verallgemeinerter_Nullpunkt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Nullpunkt_abstrakt,
   Nullpunkt_ext
      CHAR(8),
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zusatz
      CHAR(1) NOT NULL, -- Nullpunktkennung
   CHECK ( ( ( Zusatz >= 'A' AND Zusatz <= 'Z' ) OR ( Zusatz = ' ' ) ) ),
   zentraler_Nullpunkt
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Nullpunkt__in_Netzknoten (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Nullpunkt__Beginn_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__Ende_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__verbindet_VV (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung
)

CREATE TABLE Nullpunkt__hat_Nullpunktsort (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort
)

CREATE TABLE Nullpunkt_abstrakt (
   Nullpunkt_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Art_Nullpunkt_abstrakt
)

CREATE TABLE Art_Nullpunkt_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Nullpunkt_abstrakt VALUES (1,'Nullpunkt')
INSERT INTO Art_Nullpunkt_abstrakt VALUES (2,'Nullpunkt_Symbol')

CREATE TABLE Nullpunkt_Symbol (
   Nullpunkt_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_Symbol_ID) REFERENCES Nullpunkt_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Punktobjekt (
   Punktobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobjekt
      INTEGER NOT NULL REFERENCES Art_Punktobjekt,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 )
)

CREATE TABLE Art_Punktobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt VALUES (1,'oertliche_Zuordnung_SP')
INSERT INTO Art_Punktobjekt VALUES (2,'GDF_Verbindungspunkt')
INSERT INTO Art_Punktobjekt VALUES (3,'Achselementpunkt')
INSERT INTO Art_Punktobjekt VALUES (4,'Querprofilpunkt')
INSERT INTO Art_Punktobjekt VALUES (5,'Wirkungsbereich_SP')
INSERT INTO Art_Punktobjekt VALUES (6,'Anordnung_des_Messsystems')
INSERT INTO Art_Punktobjekt VALUES (7,'stat_wegweisende_Beschilderung')
INSERT INTO Art_Punktobjekt VALUES (8,'Position')
INSERT INTO Art_Punktobjekt VALUES (9,'stat_verkehrsreg_Beschilderung')
INSERT INTO Art_Punktobjekt VALUES (10,'Kilometrierung')
INSERT INTO Art_Punktobjekt VALUES (11,'Schichtbegrenzung')
INSERT INTO Art_Punktobjekt VALUES (12,'Streifenbegrenzung')
INSERT INTO Art_Punktobjekt VALUES (13,'Gewaesserkreuzung')
INSERT INTO Art_Punktobjekt VALUES (14,'Bahnkreuzung')
INSERT INTO Art_Punktobjekt VALUES (15,'Kreuzung_Strasse_Weg')
INSERT INTO Art_Punktobjekt VALUES (16,'Fussgaengerueberweg')
INSERT INTO Art_Punktobjekt VALUES (17,'Durchlass')
INSERT INTO Art_Punktobjekt VALUES (18,'Teilbauwerk')
INSERT INTO Art_Punktobjekt VALUES (19,'Bruecke')
INSERT INTO Art_Punktobjekt VALUES (20,'Verkehrszeichenbruecke')
INSERT INTO Art_Punktobjekt VALUES (21,'Tunnel_Trogbauwerk')
INSERT INTO Art_Punktobjekt VALUES (22,'Laermschutzbauwerk')
INSERT INTO Art_Punktobjekt VALUES (23,'Stuetzbauwerk')
INSERT INTO Art_Punktobjekt VALUES (24,'sonstiges_Bauwerk')
INSERT INTO Art_Punktobjekt VALUES (25,'Aufstellvorrichtung')

CREATE TABLE Punktobjekt_stat (
   Punktobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_stat_ID) REFERENCES Punktobjekt,
   Art_Punktobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_stat
)

CREATE TABLE Art_Punktobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt_stat VALUES (1,'GDF_Verbindungspunkt')
INSERT INTO Art_Punktobjekt_stat VALUES (2,'Achselementpunkt')
INSERT INTO Art_Punktobjekt_stat VALUES (3,'Querprofilpunkt')
INSERT INTO Art_Punktobjekt_stat VALUES (4,'Wirkungsbereich_SP')
INSERT INTO Art_Punktobjekt_stat VALUES (5,'Anordnung_des_Messsystems')
INSERT INTO Art_Punktobjekt_stat VALUES (6,'stat_wegweisende_Beschilderung')
INSERT INTO Art_Punktobjekt_stat VALUES (7,'Position')
INSERT INTO Art_Punktobjekt_stat VALUES (8,'stat_verkehrsreg_Beschilderung')
INSERT INTO Art_Punktobjekt_stat VALUES (9,'oertliche_Zuordnung_SP')

CREATE TABLE Punktobjekt_hist (
   Punktobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Punktobjekt,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Punktobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_hist
)

CREATE TABLE Art_Punktobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Punktobjekt_hist VALUES (1,'Kilometrierung')
INSERT INTO Art_Punktobjekt_hist VALUES (2,'Teilbauwerk')
INSERT INTO Art_Punktobjekt_hist VALUES (3,'Bruecke')
INSERT INTO Art_Punktobjekt_hist VALUES (4,'Verkehrszeichenbruecke')
INSERT INTO Art_Punktobjekt_hist VALUES (5,'Tunnel_Trogbauwerk')
INSERT INTO Art_Punktobjekt_hist VALUES (6,'Laermschutzbauwerk')
INSERT INTO Art_Punktobjekt_hist VALUES (7,'Stuetzbauwerk')
INSERT INTO Art_Punktobjekt_hist VALUES (8,'sonstiges_Bauwerk')
INSERT INTO Art_Punktobjekt_hist VALUES (9,'Schichtbegrenzung')
INSERT INTO Art_Punktobjekt_hist VALUES (10,'Streifenbegrenzung')
INSERT INTO Art_Punktobjekt_hist VALUES (11,'Gewaesserkreuzung')
INSERT INTO Art_Punktobjekt_hist VALUES (12,'Bahnkreuzung')
INSERT INTO Art_Punktobjekt_hist VALUES (13,'Kreuzung_Strasse_Weg')
INSERT INTO Art_Punktobjekt_hist VALUES (14,'Fussgaengerueberweg')
INSERT INTO Art_Punktobjekt_hist VALUES (15,'Durchlass')
INSERT INTO Art_Punktobjekt_hist VALUES (16,'Aufstellvorrichtung')

CREATE TABLE oertliche_Zuordnung (
   oertliche_Zuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   liegt_auf_Strassenpunkt
      INTEGER REFERENCES oertliche_Zuordnung_SP,
   liegt_auf_nicht_klass_Strasse
      INTEGER REFERENCES nicht_nach_ASB_klass_Strasse,
   CHECK ( ( ( liegt_auf_Strassenpunkt IS NOT NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NOT NULL ) ) AND ( ( liegt_auf_Strassenpunkt IS NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NULL ) ) )
)

CREATE TABLE oertliche_Zuordnung_SP (
   oertliche_Zuordnung_SP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_SP_ID) REFERENCES Punktobjekt_stat
)

CREATE TABLE nicht_nach_ASB_klass_Strasse (
   nicht_nach_ASB_klass_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenklasse
      VARCHAR(50) NOT NULL,
   Nummer
      INTEGER NOT NULL,
   Lage
      VARCHAR(28) NOT NULL
)

CREATE TABLE Nullpunktsort (
   Nullpunktsort_ID
      INTEGER NOT NULL PRIMARY KEY,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 )
)

CREATE TABLE Nullpunktsort__bei_Nullpunkt (
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Strassenpunkt_PoB (
   Strassenpunkt_PoB_ID
      INTEGER NOT NULL PRIMARY KEY,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 )
)

CREATE TABLE Punktobjekt_o_Bereichsobjekt (
   Punktobjekt_o_Bereichsobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobjekt_o_Bereichsobjekt
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_o_Bereichsobjekt,
   ist_Punktobjekt
      INTEGER REFERENCES Strassenpunkt_PoB,
   ist_Bereichsobjekt
      INTEGER REFERENCES Netzbereich
)

CREATE TABLE Art_Punktobjekt_o_Bereichsobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Punktobjekt_o_Bereichsobjekt VALUES (1,'Beschilderung_Lichtsignalanl')
INSERT INTO Art_Punktobjekt_o_Bereichsobjekt VALUES (2,'Fahrbahnmarkierungen')
INSERT INTO Art_Punktobjekt_o_Bereichsobjekt VALUES (3,'Schutz_und_Leiteinrichtungen')

CREATE TABLE Netzbereichskomponente (
   Netzbereichskomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzbereichskomponente
      INTEGER NOT NULL REFERENCES Art_Netzbereichskomponente
)

CREATE TABLE Art_Netzbereichskomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Netzbereichskomponente VALUES (1,'Netzbereich')
INSERT INTO Art_Netzbereichskomponente VALUES (2,'Teilabschnitt')
INSERT INTO Art_Netzbereichskomponente VALUES (3,'Strecke')

CREATE TABLE Netzbereich (
   Netzbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Netzbrch__enthaelt_Komponenten (
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich,
   Netzbereichskomponente
      INTEGER REFERENCES Netzbereichskomponente,
   auf_Abschnitt_oder_Ast
      INTEGER REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL, -- Meter
   CHECK ( Station_2>=0 )
)

CREATE TABLE Bereichsobjekt (
   Bereichsobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Bereichsobjekt
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt
)

CREATE TABLE Art_Bereichsobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt VALUES (1,'Teilbauwerk')
INSERT INTO Art_Bereichsobjekt VALUES (2,'Bruecke')
INSERT INTO Art_Bereichsobjekt VALUES (3,'Verkehrszeichenbruecke')
INSERT INTO Art_Bereichsobjekt VALUES (4,'Tunnel_Trogbauwerk')
INSERT INTO Art_Bereichsobjekt VALUES (5,'Laermschutzbauwerk')
INSERT INTO Art_Bereichsobjekt VALUES (6,'Stuetzbauwerk')
INSERT INTO Art_Bereichsobjekt VALUES (7,'sonstiges_Bauwerk')
INSERT INTO Art_Bereichsobjekt VALUES (8,'Bundesland')
INSERT INTO Art_Bereichsobjekt VALUES (9,'Regierungsbezirk')
INSERT INTO Art_Bereichsobjekt VALUES (10,'Kreis_kreisfreie_Stadt')
INSERT INTO Art_Bereichsobjekt VALUES (11,'Gemeindebezirk')
INSERT INTO Art_Bereichsobjekt VALUES (12,'Ortsteil')
INSERT INTO Art_Bereichsobjekt VALUES (13,'Land_Ministerium')
INSERT INTO Art_Bereichsobjekt VALUES (14,'Regierungspraesidium_Landesamt')
INSERT INTO Art_Bereichsobjekt VALUES (15,'Amt')
INSERT INTO Art_Bereichsobjekt VALUES (16,'Meisterei')
INSERT INTO Art_Bereichsobjekt VALUES (17,'Kreisverwaltung')
INSERT INTO Art_Bereichsobjekt VALUES (18,'Gemeindeverwaltung')
INSERT INTO Art_Bereichsobjekt VALUES (19,'UI_Vereinbarung')
INSERT INTO Art_Bereichsobjekt VALUES (20,'Baulast')
INSERT INTO Art_Bereichsobjekt VALUES (21,'Schutzzone')

CREATE TABLE Bereichsobj__hat_Netzbereich (
   Bereichsobjekt
      INTEGER NOT NULL REFERENCES Bereichsobjekt,
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich
)

CREATE TABLE Bereichsobjekt_stat (
   Bereichsobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_stat_ID) REFERENCES Bereichsobjekt,
   Art_Bereichsobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_stat
)

CREATE TABLE Art_Bereichsobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Bereichsobjekt_stat VALUES (1,'Teilbauwerk')
INSERT INTO Art_Bereichsobjekt_stat VALUES (2,'Bruecke')
INSERT INTO Art_Bereichsobjekt_stat VALUES (3,'Verkehrszeichenbruecke')
INSERT INTO Art_Bereichsobjekt_stat VALUES (4,'Tunnel_Trogbauwerk')
INSERT INTO Art_Bereichsobjekt_stat VALUES (5,'Laermschutzbauwerk')
INSERT INTO Art_Bereichsobjekt_stat VALUES (6,'Stuetzbauwerk')
INSERT INTO Art_Bereichsobjekt_stat VALUES (7,'sonstiges_Bauwerk')

CREATE TABLE Bereichsobjekt_hist (
   Bereichsobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Bereichsobjekt,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Bereichsobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_hist
)

CREATE TABLE Art_Bereichsobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt_hist VALUES (1,'Bundesland')
INSERT INTO Art_Bereichsobjekt_hist VALUES (2,'Regierungsbezirk')
INSERT INTO Art_Bereichsobjekt_hist VALUES (3,'Kreis_kreisfreie_Stadt')
INSERT INTO Art_Bereichsobjekt_hist VALUES (4,'Gemeindebezirk')
INSERT INTO Art_Bereichsobjekt_hist VALUES (5,'Ortsteil')
INSERT INTO Art_Bereichsobjekt_hist VALUES (6,'Land_Ministerium')
INSERT INTO Art_Bereichsobjekt_hist VALUES (7,'Regierungspraesidium_Landesamt')
INSERT INTO Art_Bereichsobjekt_hist VALUES (8,'Amt')
INSERT INTO Art_Bereichsobjekt_hist VALUES (9,'Meisterei')
INSERT INTO Art_Bereichsobjekt_hist VALUES (10,'Kreisverwaltung')
INSERT INTO Art_Bereichsobjekt_hist VALUES (11,'Gemeindeverwaltung')
INSERT INTO Art_Bereichsobjekt_hist VALUES (12,'UI_Vereinbarung')
INSERT INTO Art_Bereichsobjekt_hist VALUES (13,'Baulast')
INSERT INTO Art_Bereichsobjekt_hist VALUES (14,'Schutzzone')

CREATE TABLE Streckenobjekt (
   Streckenobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Streckenobjekt
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt
)

CREATE TABLE Art_Streckenobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Streckenobjekt VALUES (1,'Entwurfselement_Kreisbogen')
INSERT INTO Art_Streckenobjekt VALUES (2,'Entwurfselement_Klothoide')
INSERT INTO Art_Streckenobjekt VALUES (3,'Entwurfselement_Gerade')
INSERT INTO Art_Streckenobjekt VALUES (4,'Anzahl_Fahrstreifen')
INSERT INTO Art_Streckenobjekt VALUES (5,'Insassen_min_Anzahl')
INSERT INTO Art_Streckenobjekt VALUES (6,'Ueberholverbot')
INSERT INTO Art_Streckenobjekt VALUES (7,'max_Hoehe')
INSERT INTO Art_Streckenobjekt VALUES (8,'max_Breite')
INSERT INTO Art_Streckenobjekt VALUES (9,'max_Laenge')
INSERT INTO Art_Streckenobjekt VALUES (10,'max_Gewicht')
INSERT INTO Art_Streckenobjekt VALUES (11,'max_Achsgewicht')
INSERT INTO Art_Streckenobjekt VALUES (12,'max_Geschwindigkeit')
INSERT INTO Art_Streckenobjekt VALUES (13,'Zugangsbeschraenkung')
INSERT INTO Art_Streckenobjekt VALUES (14,'Gesperrt')
INSERT INTO Art_Streckenobjekt VALUES (15,'Fkt_d_Verb_im_Knotenpktber')
INSERT INTO Art_Streckenobjekt VALUES (16,'Bergpass')
INSERT INTO Art_Streckenobjekt VALUES (17,'Verkehrsbedeutung')
INSERT INTO Art_Streckenobjekt VALUES (18,'Spur_fuer_Rettungsfahrzeuge')
INSERT INTO Art_Streckenobjekt VALUES (19,'Strassenfunktion')
INSERT INTO Art_Streckenobjekt VALUES (20,'Aussichtswert')
INSERT INTO Art_Streckenobjekt VALUES (21,'Staugefahr')
INSERT INTO Art_Streckenobjekt VALUES (22,'gebuehrenpflichtig')
INSERT INTO Art_Streckenobjekt VALUES (23,'Durchschnittsgeschwindigkeit')
INSERT INTO Art_Streckenobjekt VALUES (24,'Fahrbahntrennung')
INSERT INTO Art_Streckenobjekt VALUES (25,'Trassenbreite')
INSERT INTO Art_Streckenobjekt VALUES (26,'Fahrbahnbreite')
INSERT INTO Art_Streckenobjekt VALUES (27,'Fussweg')
INSERT INTO Art_Streckenobjekt VALUES (28,'Radweg')
INSERT INTO Art_Streckenobjekt VALUES (29,'Strassenentwaesserung')
INSERT INTO Art_Streckenobjekt VALUES (30,'ZEB_Objekt')
INSERT INTO Art_Streckenobjekt VALUES (31,'Erfassung_Gesamtverkehr')
INSERT INTO Art_Streckenobjekt VALUES (32,'Block')
INSERT INTO Art_Streckenobjekt VALUES (33,'OD_FS')
INSERT INTO Art_Streckenobjekt VALUES (34,'Widmung')
INSERT INTO Art_Streckenobjekt VALUES (35,'Schicht')
INSERT INTO Art_Streckenobjekt VALUES (36,'Querschnittstreifen')
INSERT INTO Art_Streckenobjekt VALUES (37,'Bauklasse_Oberbau')
INSERT INTO Art_Streckenobjekt VALUES (38,'Bauweise_Oberbau')
INSERT INTO Art_Streckenobjekt VALUES (39,'Regelquerschnitt')
INSERT INTO Art_Streckenobjekt VALUES (40,'Bahnigkeit')
INSERT INTO Art_Streckenobjekt VALUES (41,'Fahrbahnlaengsneigung')
INSERT INTO Art_Streckenobjekt VALUES (42,'Fahrbahnquerneigung')
INSERT INTO Art_Streckenobjekt VALUES (43,'Hindernis')
INSERT INTO Art_Streckenobjekt VALUES (44,'Leitung')
INSERT INTO Art_Streckenobjekt VALUES (45,'Markierung')
INSERT INTO Art_Streckenobjekt VALUES (46,'Schutzplanke')
INSERT INTO Art_Streckenobjekt VALUES (47,'Nebenanlage')
INSERT INTO Art_Streckenobjekt VALUES (48,'Rastanlage_nicht_bew')
INSERT INTO Art_Streckenobjekt VALUES (49,'Rastanlage_bew')
INSERT INTO Art_Streckenobjekt VALUES (50,'Nebenbetrieb')
INSERT INTO Art_Streckenobjekt VALUES (51,'SB_Wirkungsbereiche')
INSERT INTO Art_Streckenobjekt VALUES (52,'raeumlicher_Gueltigkeitsber')

CREATE TABLE Streckenobjekt__hat_Strecke (
   Streckenobjekt
      INTEGER NOT NULL REFERENCES Streckenobjekt,
   Strecke
      INTEGER NOT NULL REFERENCES Strecke
)

CREATE TABLE Streckenobjekt_stat (
   Streckenobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_stat_ID) REFERENCES Streckenobjekt,
   Art_Streckenobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_stat
)

CREATE TABLE Art_Streckenobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Streckenobjekt_stat VALUES (1,'Entwurfselement_Kreisbogen')
INSERT INTO Art_Streckenobjekt_stat VALUES (2,'Entwurfselement_Klothoide')
INSERT INTO Art_Streckenobjekt_stat VALUES (3,'Entwurfselement_Gerade')
INSERT INTO Art_Streckenobjekt_stat VALUES (4,'ZEB_Objekt')
INSERT INTO Art_Streckenobjekt_stat VALUES (5,'Strassenentwaesserung')
INSERT INTO Art_Streckenobjekt_stat VALUES (6,'Anzahl_Fahrstreifen')
INSERT INTO Art_Streckenobjekt_stat VALUES (7,'Insassen_min_Anzahl')
INSERT INTO Art_Streckenobjekt_stat VALUES (8,'Ueberholverbot')
INSERT INTO Art_Streckenobjekt_stat VALUES (9,'max_Hoehe')
INSERT INTO Art_Streckenobjekt_stat VALUES (10,'max_Breite')
INSERT INTO Art_Streckenobjekt_stat VALUES (11,'max_Laenge')
INSERT INTO Art_Streckenobjekt_stat VALUES (12,'max_Gewicht')
INSERT INTO Art_Streckenobjekt_stat VALUES (13,'max_Achsgewicht')
INSERT INTO Art_Streckenobjekt_stat VALUES (14,'max_Geschwindigkeit')
INSERT INTO Art_Streckenobjekt_stat VALUES (15,'Zugangsbeschraenkung')
INSERT INTO Art_Streckenobjekt_stat VALUES (16,'Gesperrt')
INSERT INTO Art_Streckenobjekt_stat VALUES (17,'Fkt_d_Verb_im_Knotenpktber')
INSERT INTO Art_Streckenobjekt_stat VALUES (18,'Bergpass')
INSERT INTO Art_Streckenobjekt_stat VALUES (19,'Verkehrsbedeutung')
INSERT INTO Art_Streckenobjekt_stat VALUES (20,'Spur_fuer_Rettungsfahrzeuge')
INSERT INTO Art_Streckenobjekt_stat VALUES (21,'Strassenfunktion')
INSERT INTO Art_Streckenobjekt_stat VALUES (22,'Aussichtswert')
INSERT INTO Art_Streckenobjekt_stat VALUES (23,'Staugefahr')
INSERT INTO Art_Streckenobjekt_stat VALUES (24,'gebuehrenpflichtig')
INSERT INTO Art_Streckenobjekt_stat VALUES (25,'Durchschnittsgeschwindigkeit')
INSERT INTO Art_Streckenobjekt_stat VALUES (26,'Fahrbahntrennung')
INSERT INTO Art_Streckenobjekt_stat VALUES (27,'Trassenbreite')
INSERT INTO Art_Streckenobjekt_stat VALUES (28,'Fahrbahnbreite')
INSERT INTO Art_Streckenobjekt_stat VALUES (29,'Fussweg')
INSERT INTO Art_Streckenobjekt_stat VALUES (30,'Radweg')
INSERT INTO Art_Streckenobjekt_stat VALUES (31,'Erfassung_Gesamtverkehr')

CREATE TABLE Streckenobjekt_hist (
   Streckenobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Streckenobjekt,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Streckenobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_hist
)

CREATE TABLE Art_Streckenobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(27) NOT NULL
)

INSERT INTO Art_Streckenobjekt_hist VALUES (1,'Block')
INSERT INTO Art_Streckenobjekt_hist VALUES (2,'OD_FS')
INSERT INTO Art_Streckenobjekt_hist VALUES (3,'Widmung')
INSERT INTO Art_Streckenobjekt_hist VALUES (4,'Leitung')
INSERT INTO Art_Streckenobjekt_hist VALUES (5,'Markierung')
INSERT INTO Art_Streckenobjekt_hist VALUES (6,'Schutzplanke')
INSERT INTO Art_Streckenobjekt_hist VALUES (7,'Nebenanlage')
INSERT INTO Art_Streckenobjekt_hist VALUES (8,'Rastanlage_nicht_bew')
INSERT INTO Art_Streckenobjekt_hist VALUES (9,'Rastanlage_bew')
INSERT INTO Art_Streckenobjekt_hist VALUES (10,'Nebenbetrieb')
INSERT INTO Art_Streckenobjekt_hist VALUES (11,'Schicht')
INSERT INTO Art_Streckenobjekt_hist VALUES (12,'Querschnittstreifen')
INSERT INTO Art_Streckenobjekt_hist VALUES (13,'Bauklasse_Oberbau')
INSERT INTO Art_Streckenobjekt_hist VALUES (14,'Bauweise_Oberbau')
INSERT INTO Art_Streckenobjekt_hist VALUES (15,'Regelquerschnitt')
INSERT INTO Art_Streckenobjekt_hist VALUES (16,'Bahnigkeit')
INSERT INTO Art_Streckenobjekt_hist VALUES (17,'Fahrbahnlaengsneigung')
INSERT INTO Art_Streckenobjekt_hist VALUES (18,'Fahrbahnquerneigung')
INSERT INTO Art_Streckenobjekt_hist VALUES (19,'Hindernis')
INSERT INTO Art_Streckenobjekt_hist VALUES (20,'SB_Wirkungsbereiche')
INSERT INTO Art_Streckenobjekt_hist VALUES (21,'raeumlicher_Gueltigkeitsber')

CREATE TABLE Strecke (
   Strecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strecke_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Strecke_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Strecke__entlang_Teilabschnitt (
   Strecke
      INTEGER NOT NULL REFERENCES Strecke,
   Position
      INTEGER NOT NULL,
   PRIMARY KEY ( Strecke , Position ),
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL NOT NULL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL NOT NULL, -- Meter
   CHECK ( Station_2>=0 )
)

CREATE TABLE Teilnetzkomponente (
   Teilnetzkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Art_Teilnetzkomponente
)

CREATE TABLE Art_Teilnetzkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Teilnetzkomponente VALUES (1,'Teilnetz')
INSERT INTO Art_Teilnetzkomponente VALUES (2,'Route')
INSERT INTO Art_Teilnetzkomponente VALUES (3,'Strassenelement')

CREATE TABLE Teilnetz (
   Teilnetz_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennzeichen_Teilnetz
      VARCHAR(6),
   Beschreibung_Teilnetz
      VARCHAR(60)
)

CREATE TABLE Teilnetz__enthaelt_Komponente (
   Teilnetz
      INTEGER NOT NULL REFERENCES Teilnetz,
   Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Teilnetzkomponente
)

CREATE TABLE Routenkomponente (
   Routenkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Routenkomponente
      INTEGER NOT NULL REFERENCES Art_Routenkomponente
)

CREATE TABLE Art_Routenkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Routenkomponente VALUES (1,'Route')
INSERT INTO Art_Routenkomponente VALUES (2,'Strassenelement')

CREATE TABLE Routenkomp__hat_Vorgaenger (
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente,
   Routenkomponente_2
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Route (
   Route_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Route_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Route__entlang_Komponente (
   Route
      INTEGER NOT NULL REFERENCES Route,
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Route__fuer_Teilbauwerk (
   Route
      INTEGER NOT NULL REFERENCES Route,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Bauwerke.Teilbauwerk_abstrakt
)

CREATE TABLE Strassenelement (
   Strassenelement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Strassenelement_ext
      CHAR(16),
   gueltig_von
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10) NOT NULL, -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   RDS_TMC_Code
      VARCHAR(12),
   beginnt_bei_NPO
      INTEGER NOT NULL REFERENCES Nullpunktsort,
   endet_bei_NPO
      INTEGER NOT NULL REFERENCES Nullpunktsort
)

CREATE TABLE Kilometrierung (
   Kilometrierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kilometrierung_ID) REFERENCES Punktobjekt_hist,
   Kilometrierung
      REAL NOT NULL, -- Kilometer
   CHECK ( Kilometrierung>=0 )
)

CREATE TABLE Betriebskilometer__in_Block (
   Betriebskilometer
      INTEGER NOT NULL REFERENCES Kilometrierung,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Block (
   Block_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Block_ID) REFERENCES Streckenobjekt_hist,
   Blocknummer
      INTEGER NOT NULL,
   km_Anfang
      REAL NOT NULL,
   km_Ende
      REAL NOT NULL
)

CREATE TABLE Block__auf_Strasse (
   Block
      INTEGER NOT NULL REFERENCES Block,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE GDF_Verbindungspunkt (
   GDF_Verbindungspunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES Punktobjekt_stat,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES verallgemeinerter_Nullpunkt,
   entspricht_Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt
)

CREATE TABLE GDF_Verbindungselement (
   GDF_Verbindungselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (GDF_Verbindungselement_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   beginnt_bei_verallg_Nullpunkt
      INTEGER NOT NULL REFERENCES verallgemeinerter_Nullpunkt,
   endet_bei_verallg_Nullpunkt
      INTEGER NOT NULL REFERENCES verallgemeinerter_Nullpunkt,
   gehoert_zu_Nullpunkt
      INTEGER REFERENCES Nullpunkt,
   entspricht_Strassenelement
      INTEGER REFERENCES Strassenelement
)

CREATE TABLE verallgemeinerter_Nullpunkt (
   verallgemeinerter_Nullpunkt_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Entwurfselement (
   Entwurfselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_ID) REFERENCES Streckenobjekt_stat,
   Richtungsw_Tangente_am_Anfang
      REAL, -- Winkel
   beginnt_bei_Vermessungspunkt
      INTEGER NOT NULL,
   endet_bei_Vermessungspunkt
      INTEGER NOT NULL
)

CREATE TABLE Entwurfselement_Kreisbogen (
   Entwurfselement_Kreisbogen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Kreisbogen_ID) REFERENCES Entwurfselement,
   Radius
      REAL NOT NULL, -- Meter
   CHECK ( Radius>=0 )
)

CREATE TABLE Entwurfselement_Klothoide (
   Entwurfselement_Klothoide_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Klothoide_ID) REFERENCES Entwurfselement,
   Radius_am_Anfang
      REAL NOT NULL, -- Meter
   CHECK ( Radius_am_Anfang>=0 ),
   Radius_am_Ende
      REAL, -- Meter
   CHECK ( Radius_am_Ende>=0 ),
   Parameter
      REAL NOT NULL, -- Meter
   CHECK ( Parameter>=0 )
)

CREATE TABLE Entwurfselement_Gerade (
   Entwurfselement_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Gerade_ID) REFERENCES Entwurfselement
)

