CREATE SCHEMA Bauwerke

-- Historie:
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Bauwerk, Teilbauwerk und Strassenbaudienststelle
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Bauwerk (
   Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_ID) REFERENCES Bauwerk_abstrakt,
   Bauwerksnummer
      VARCHAR(7) NOT NULL,
   Interne_Bauwerksnummer
      VARCHAR(12),
   Interner_Sortierschluessel
      VARCHAR(15),
   Bauwerksname
      VARCHAR(50),
   naechstgelegener_Ort
      VARCHAR(50),
   Bemerkungen
      VARCHAR(255),
   Anzahl_Teilbauwerke
      INTEGER
)

CREATE TABLE Bauwerk__besteht_aus_Teilbauw (
   Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bauwerk_abstrakt (
   Bauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Bauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Bauwerk_abstrakt
)

CREATE TABLE Art_Bauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Bauwerk_abstrakt VALUES (1,'Bauwerk')
INSERT INTO Art_Bauwerk_abstrakt VALUES (2,'Bauwerk_Symbol')

CREATE TABLE Bauwerk_Symbol (
   Bauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_Symbol_ID) REFERENCES Bauwerk_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE Teilbauwerk (
   Teilbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Strassennetz.Bereichsobjekt_stat,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Teilbauwerk_abstrakt,
   Teilbauwerksnummer
      VARCHAR(2) NOT NULL,
   Name_des_Teilbauwerks
      VARCHAR(50),
   Interner_Sortierschluessel
      VARCHAR(15),
   Amt
      VARCHAR(6),
   Meisterei
      VARCHAR(6),
   Unterhaltung_Instandsetzung
      VARCHAR(15),
   Bauwerksart
      VARCHAR(15),
   Stadium_Teilbauwerk
      VARCHAR(15),
   Bauwerksakte_Nummer
      VARCHAR(50),
   Baulast_Konstruktion
      VARCHAR(15),
   Baujahr
      INTEGER, -- Jahr
   CHECK ( ( Baujahr >= 1900 ) AND ( Baujahr <= 2099 ) ),
   Denkmalschutz
      VARCHAR(50),
   Unterlagen
      VARCHAR(255),
   Datenerfassung_abgeschlossen
      VARCHAR(15),
   Konstruktion
      VARCHAR(50),
   Bemerkungen
      VARCHAR(255),
   hat_Bauwerkseinzelheiten
      INTEGER NOT NULL REFERENCES Ingenieurbauwerke.Bauwerkseinzelheiten,
   gehoert_zu_Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk_abstrakt
)

CREATE TABLE Teilbw__hat_Strbaudienststelle (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Strassenbaudienststelle_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Strassenbaudienststelle_abstrakt
)

CREATE TABLE Teilbauwerk__hat_Route (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Route
      INTEGER NOT NULL REFERENCES Strassennetz.Route
)

CREATE TABLE Teilbauwerk__hat_Sachverhalt (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Teilbw__hat_Bauwbeschilderung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Bauwerksbeschilderung
      INTEGER NOT NULL REFERENCES Bauwerksbeschilderung
)

CREATE TABLE Teilbw__hat_Bauwerksbelaege (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Bauwerksbelaege
      INTEGER NOT NULL REFERENCES Bauwerksbelaege
)

CREATE TABLE Teilbw__hat_Hauptbaust_Beton (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hauptbaustoff_Beton
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Beton
)

CREATE TABLE Teilbw__hat_Hauptbaust_Stahl (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst
)

CREATE TABLE Teilbw__hat_Hauptbaust_Verbwst (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hauptbaustoff_Verbundwerkst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Verbundwerkst
)

CREATE TABLE Teilbw__hat_Schadensd_abg_Prfg (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Schadensdaten_abgeschl_Prfg
      INTEGER NOT NULL REFERENCES Schadensdaten_abgeschl_Prfg
)

CREATE TABLE Teilbw__hat_Pruefgsd_abg_Prfg (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Pruefungsdaten_abgeschl_Prfg
      INTEGER NOT NULL REFERENCES Pruefungsdaten_abgeschl_Prfg
)

CREATE TABLE Teilbw__hat_gegw_dok_Schadstd (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   gegenw_dokum_Schadensstand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Schadensstand
)

CREATE TABLE Teilbw__hat_gegw_dok_Pruefstd (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   gegenw_dokum_Pruefungsstand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Pruefungsstand
)

CREATE TABLE Teilbw__hat_durchgef_Prf_Mess (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   durchgef_Pruefungen_Messungen
      INTEGER NOT NULL REFERENCES durchgef_Pruefungen_Messungen
)

CREATE TABLE Teilbw__hat_Prueffz_Pruefger (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Prueffahrzeuge_Pruefgeraete
      INTEGER NOT NULL REFERENCES Prueffahrzeuge_Pruefgeraete
)

CREATE TABLE Teilbw__hat_Pruefanweisungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Pruefanweisungen
      INTEGER NOT NULL REFERENCES Pruefanweisungen
)

CREATE TABLE Teilbw__hat_Verwaltungsmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb
)

CREATE TABLE Teilbw__hat_Bau_u_Erhaltmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme
)

CREATE TABLE Teilbw__hat_Anlagen_Bauwbuch (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Anlagen_Bauwerksbuch
      INTEGER NOT NULL REFERENCES Anlagen_Bauwerksbuch
)

CREATE TABLE Teilbw__hat_Entwue_und_Berechn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Entwuerfe_und_Berechnungen
      INTEGER NOT NULL REFERENCES Entwuerfe_und_Berechnungen
)

CREATE TABLE Teilbauwerk__hat_Gestaltungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gestaltungen
      INTEGER NOT NULL REFERENCES Gestaltungen
)

CREATE TABLE Teilbw__hat_Leitungen_an_Bauw (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Leitungen_an_Bauwerken
      INTEGER NOT NULL REFERENCES Leitungen_an_Bauwerken
)

CREATE TABLE Teilbw__hat_stat_System_Tragf (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   statisches_System_Tragfaehigkt
      INTEGER NOT NULL REFERENCES statisches_System_Tragfaehigkt
)

CREATE TABLE Teilbauwerk__hat_Vorspannungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Vorspannungen
      INTEGER NOT NULL REFERENCES Vorspannungen
)

CREATE TABLE Teilbauwerk__hat_Gruendungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gruendungen
      INTEGER NOT NULL REFERENCES Gruendungen
)

CREATE TABLE Teilbw__hat_Erd_und_Felsanker (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Erd_und_Felsanker
      INTEGER NOT NULL REFERENCES Erd_und_Felsanker
)

CREATE TABLE Teilbw__hat_Brueckseil_u_Kabel (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Brueckenseile_und_kabel
      INTEGER NOT NULL REFERENCES Brueckenseile_und_kabel
)

CREATE TABLE Teilbauwerk__hat_Lager (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Lager
      INTEGER NOT NULL REFERENCES Lager
)

CREATE TABLE Teilbw__hat_Fahrbuebergkonstr (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Fahrbahnuebergangskonstruktion
      INTEGER NOT NULL REFERENCES Fahrbahnuebergangskonstruktion
)

CREATE TABLE Teilbauwerk__hat_Abdichtungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Abdichtungen
      INTEGER NOT NULL REFERENCES Abdichtungen
)

CREATE TABLE Teilbauwerk__hat_Kappe (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kappe
      INTEGER NOT NULL REFERENCES Kappe
)

CREATE TABLE Teilbw__hat_Schutzeinrichtgen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Schutzeinrichtungen
      INTEGER NOT NULL REFERENCES Schutzeinrichtungen
)

CREATE TABLE Teilbauwerk__hat_Ausstattung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Ausstattung
      INTEGER NOT NULL REFERENCES Ausstattung
)

CREATE TABLE Teilbauwerk__hat_Verfuellungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verfuellungen
      INTEGER NOT NULL REFERENCES Verfuellungen
)

CREATE TABLE Teilbw__hat_Betonersatz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Betonersatz_nach_ZTV_SIB
      INTEGER NOT NULL REFERENCES Betonersatz_nach_ZTV_SIB
)

CREATE TABLE Teilbw__hat_Oberflaechenschutz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Oberflschutz_nach_ZTV_SIB
      INTEGER NOT NULL REFERENCES Oberflschutz_nach_ZTV_SIB
)

CREATE TABLE Teilbw__hat_Reaktharzg_Duennb (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Reaktionsharzgeb_Duennbelaege
      INTEGER NOT NULL REFERENCES Reaktionsharzgeb_Duennbelaege
)

CREATE TABLE Teilbauwerk__von_Hindernis (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hindernis
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Hindernis
)

CREATE TABLE Teilbauwerk__von_Kreuzung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kreuzung_Strasse_Weg
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Kreuzung_Strasse_Weg
)

CREATE TABLE Teilbauwerk_abstrakt (
   Teilbauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Teilbauwerk_abstrakt
)

CREATE TABLE Art_Teilbauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Teilbauwerk_abstrakt VALUES (1,'Teilbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (2,'Bruecke')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (3,'Verkehrszeichenbruecke')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (4,'Tunnel_Trogbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (5,'Laermschutzbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (6,'Stuetzbauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (7,'sonstiges_Bauwerk')
INSERT INTO Art_Teilbauwerk_abstrakt VALUES (8,'Teilbauwerk_Symbol')

CREATE TABLE Teilbauwerk_Symbol (
   Teilbauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_Symbol_ID) REFERENCES Teilbauwerk_abstrakt,
   Kennung
      CHAR(9) NOT NULL
)

CREATE TABLE Sachverhalt (
   Sachverhalt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Lage_Sachverhalt
      VARCHAR(15),
   Art_des_Sachverhaltes
      VARCHAR(15),
   Name_des_Sachverhaltes
      VARCHAR(255),
   Strassenklasse_des_Sachverh
      CHAR(6),
   Strassennummer_des_Sachverh
      INTEGER,
   Strassenzusatz
      CHAR(1),
   Unterhaltungszuordnung
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Sachverhalt__von_Teilbauwerk (
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bauwerksbeschilderung (
   Bauwerksbeschilderung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Schild_StVO_Zeichennummer
      VARCHAR(15),
   Schild_Bezeichnung
      VARCHAR(50),
   Schild_Mengenangabe
      VARCHAR(50),
   Schild_Angabe_Zusatzschild
      VARCHAR(50),
   Bauwerksbeschild_Bemerkung
      VARCHAR(255)
)

CREATE TABLE Bauwerksbelaege (
   Bauwerksbelaege_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Belaege
      VARCHAR(15),
   Deckschichtkennzeichnung
      INTEGER REFERENCES Logical_Types.Boolean,
   Belaege_Einbauort
      VARCHAR(255),
   Schichtnummer
      INTEGER,
   Schichtdicke
      REAL, -- Millimeter
   CHECK ( Schichtdicke>=0 ),
   Einbaudatum
      CHAR(10), -- Datum
   CHECK ( Einbaudatum LIKE '__.__.____' ),
   Einbauflaeche
      REAL, -- Quadratmeter
   CHECK ( Einbauflaeche>=0 ),
   ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Entwuerfe_und_Berechnungen (
   Entwuerfe_und_Berechnungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Entw_und_Ber
      VARCHAR(15),
   Aufsteller_Entw_und_Ber
      VARCHAR(80),
   Bearbeiter_Entw_und_Ber
      VARCHAR(80),
   Aufstellungsjahr_Entw_und_Ber
      INTEGER, -- Jahr
   CHECK ( ( Aufstellungsjahr_Entw_und_Ber >= 1900 ) AND ( Aufstellungsjahr_Entw_und_Ber <= 2099 ) ),
   Bemerkungen_zu_Entw_und_Ber
      VARCHAR(255)
)

CREATE TABLE Bruecke (
   Bruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bruecke_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Bruecke
      REAL, -- Meter
   CHECK ( Gesamtlaenge_Bruecke>=0 ),
   Breite_Bruecke
      REAL, -- Meter
   CHECK ( Breite_Bruecke>=0 ),
   Gesamtbreite_Bruecke
      REAL, -- Meter
   CHECK ( Gesamtbreite_Bruecke>=0 ),
   Brueckenflaeche
      REAL, -- Quadratmeter
   CHECK ( Brueckenflaeche>=0 ),
   Zwischenraum_Ueberbauten
      REAL, -- Meter
   CHECK ( Zwischenraum_Ueberbauten>=0 ),
   Konstruktionshoehe_min
      REAL, -- Meter
   CHECK ( Konstruktionshoehe_min>=0 ),
   Konstruktionshoehe_max
      REAL, -- Meter
   CHECK ( Konstruktionshoehe_max>=0 ),
   Anzahl_Felder_Bruecke
      INTEGER,
   Anzahl_Ueberbauten_Bruecke
      INTEGER,
   Laengsneigung_max
      REAL, -- Prozent
   Querneigung_max
      REAL, -- Prozent
   Kruemmung
      VARCHAR(15),
   Bauwerkswinkel
      REAL, -- Gon
   CHECK ( Bauwerkswinkel>=0 ),
   Winkelrichtung
      VARCHAR(15),
   Querschnitt_Ueberbau
      VARCHAR(15),
   Querschnitt_Haupttragwerk
      VARCHAR(15),
   Bauverfahren_Ueberbau
      VARCHAR(15),
   Konstr_Massn_nachtr_Verstaerk
      VARCHAR(15),
   maximale_Ueberschuettungshoehe
      REAL, -- Meter
   CHECK ( maximale_Ueberschuettungshoehe>=0 ),
   minimale_Ueberschuettungshoehe
      REAL, -- Meter
   CHECK ( minimale_Ueberschuettungshoehe>=0 ),
   lichte_Hoehe
      REAL, -- Meter
   CHECK ( lichte_Hoehe>=0 ),
   lichte_Weite_b_Einfeldbruecke
      REAL, -- Meter
   CHECK ( lichte_Weite_b_Einfeldbruecke>=0 ),
   Bemerkungen_zum_Baugrund
      VARCHAR(255),
   Bemerkungen_zur_Bruecke
      VARCHAR(255)
)

CREATE TABLE Teilbw__hat_Brueckenf_Stuetz (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Verkehrszeichenbruecke (
   Verkehrszeichenbruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrszeichenbruecke_ID) REFERENCES Teilbauwerk,
   Querschnitt_Stiel
      VARCHAR(15),
   Querschnitt_Riegel
      VARCHAR(15),
   Gesamtlaenge_des_Riegels
      REAL, -- Meter
   CHECK ( Gesamtlaenge_des_Riegels>=0 ),
   Besichtigungs_Wartungsoeffnung
      VARCHAR(15),
   Befest_Konstr_Schilder_Signalg
      VARCHAR(15),
   Bemerkung_Verkehrsz_Bruecke
      VARCHAR(255)
)

CREATE TABLE Tunnel_Trogbauwerk (
   Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnel_Trogbauwerk_ID) REFERENCES Teilbauwerk,
   Gradiente
      VARCHAR(15),
   Rundungshalbmesser
      REAL, -- Meter
   CHECK ( Rundungshalbmesser>=0 ),
   minimale_Laengsneigung
      REAL, -- Prozent
   maximale_Laengsneigung
      REAL, -- Prozent
   minimaler_Radius_im_Grundriss
      REAL, -- Meter
   CHECK ( minimaler_Radius_im_Grundriss>=0 ),
   minimale_Ueberdeckungshoehe
      REAL, -- Meter
   CHECK ( minimale_Ueberdeckungshoehe>=0 ),
   maximale_Ueberdeckungshoehe
      REAL, -- Meter
   CHECK ( maximale_Ueberdeckungshoehe>=0 ),
   Hoehe_rel_NN_in_Tunnelmitte
      REAL, -- Meter
   CHECK ( Hoehe_rel_NN_in_Tunnelmitte>=0 ),
   Bauwerkslaenge
      REAL, -- Meter
   CHECK ( Bauwerkslaenge>=0 ),
   geschl_Laenge_der_Tunnelroehre
      REAL, -- Meter
   CHECK ( geschl_Laenge_der_Tunnelroehre>=0 ),
   Tunnelflaeche
      REAL, -- Quadratmeter
   CHECK ( Tunnelflaeche>=0 ),
   Bauweise
      VARCHAR(15),
   Querschnitt
      VARCHAR(15),
   Ausbruchflaeche
      REAL, -- Quadratmeter
   CHECK ( Ausbruchflaeche>=0 ),
   Sicherung
      VARCHAR(255),
   Geologie
      VARCHAR(15),
   Grund_und_Gebirgswasserverh
      VARCHAR(255),
   Bauverfahren
      VARCHAR(15),
   Vortriebsverfahren
      VARCHAR(15),
   Bemerkungen_zum_Tunnel_Trogbau
      VARCHAR(255)
)

CREATE TABLE Tunnel_Trogbw__hat_Segmente (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Segment_Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Segment_Tunnel_Trogbauwerk
)

CREATE TABLE Tunnel_Trogbw__hat_Tunbeleucht (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelbeleuchtung
      INTEGER NOT NULL REFERENCES Tunnelbeleuchtung
)

CREATE TABLE Tunnel_Trogbw__hat_Tunnellueft (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnellueftung
      INTEGER NOT NULL REFERENCES Tunnellueftung
)

CREATE TABLE Tunnel_Trogbw__hat_Zentr_Anl (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Zentrale_Anlagen
      INTEGER NOT NULL REFERENCES Tunnel_Zentrale_Anlagen
)

CREATE TABLE Tunnel_Trogbw__hat_Tunsicherh (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelsicherheit
      INTEGER NOT NULL REFERENCES Tunnelsicherheit
)

CREATE TABLE Tunnel_Trogbw__hat_Tunverkeinr (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Verkehrseinrichtungen
      INTEGER NOT NULL REFERENCES Tunnel_Verkehrseinrichtungen
)

CREATE TABLE Laermschutzbauwerk (
   Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laermschutzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge
      REAL, -- Meter
   CHECK ( Gesamtlaenge>=0 ),
   Flaeche_des_Laermschirmes
      REAL, -- Quadratmeter
   CHECK ( Flaeche_des_Laermschirmes>=0 ),
   Bemerkungen_zum_Laermschutzbw
      VARCHAR(255)
)

CREATE TABLE Laermschbw__hat_Segmente (
   Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Laermschutzbauwerk,
   Segment_Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Laermschutzbauwerk
)

CREATE TABLE Stuetzbauwerk (
   Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Stuetzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Stuetzbauwerk
      REAL, -- Meter
   CHECK ( Gesamtlaenge_Stuetzbauwerk>=0 ),
   Flaeche_Stuetzbauwerk
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Stuetzbauwerk>=0 ),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Stuetzbauwerk__hat_Segmente (
   Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Stuetzbauwerk,
   Segment_Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Stuetzbauwerk
)

CREATE TABLE sonstiges_Bauwerk (
   sonstiges_Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (sonstiges_Bauwerk_ID) REFERENCES Teilbauwerk,
   Stuetzweite_sonstiges_Bauwerk
      REAL, -- Meter
   CHECK ( Stuetzweite_sonstiges_Bauwerk>=0 ),
   Beschreibung_sonstiges_Bauwerk
      VARCHAR(255)
)

CREATE TABLE Brueckenfeld_Stuetzung (
   Brueckenfeld_Stuetzung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Stuetzung
      VARCHAR(15),
   Feldnummer
      INTEGER,
   Stuetzweite
      REAL, -- Meter
   CHECK ( Stuetzweite>=0 ),
   Stuetzungshoehe
      REAL, -- Meter
   CHECK ( Stuetzungshoehe>=0 ),
   Anzahl_d_Stuetzen_einer_Reihe
      INTEGER,
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Segment_Tunnel_Trogbauwerk (
   Segment_Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Segmentlaenge
      REAL, -- Meter
   CHECK ( Segmentlaenge>=0 ),
   Oberflaeche_Tunneldecke
      VARCHAR(15),
   Oberflaeche_Tunnelwaende
      VARCHAR(15),
   Hoehe_Segmentanfang_rechts
      REAL, -- Meter
   CHECK ( Hoehe_Segmentanfang_rechts>=0 ),
   Hoehe_Segmentanfang_links
      REAL, -- Meter
   CHECK ( Hoehe_Segmentanfang_links>=0 ),
   Hoehe_Segmentende_rechts
      REAL, -- Meter
   CHECK ( Hoehe_Segmentende_rechts>=0 ),
   Hoehe_Segmentende_links
      REAL, -- Meter
   CHECK ( Hoehe_Segmentende_links>=0 ),
   Bemerkungen_Segm_Tunnel_Trogbw
      VARCHAR(255)
)

CREATE TABLE Segment_Laermschutzbauwerk (
   Segment_Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Segmentlaenge_Laermschutz
      REAL, -- Meter
   CHECK ( Segmentlaenge_Laermschutz>=0 ),
   Hoehe_Segmentanfang
      REAL, -- Meter
   CHECK ( Hoehe_Segmentanfang>=0 ),
   Hoehe_Segmentende
      REAL, -- Meter
   CHECK ( Hoehe_Segmentende>=0 ),
   Pfostenabstand
      REAL, -- Meter
   CHECK ( Pfostenabstand>=0 ),
   Standort_des_Pfostens
      VARCHAR(15),
   Untergrund
      VARCHAR(15),
   Fangvorrichtung
      VARCHAR(15),
   Vogelschutz
      VARCHAR(15),
   akustische_Eig_Vorsatzschale
      VARCHAR(15),
   Pflanzungen_Verkehrsseite
      VARCHAR(15),
   Pflanzungen_Anliegerseite
      VARCHAR(15),
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_Laermschutz
      VARCHAR(255)
)

CREATE TABLE Segment_Stuetzbauwerk (
   Segment_Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   Segmentlaenge_Stuetzbauwerk
      REAL, -- Meter
   CHECK ( Segmentlaenge_Stuetzbauwerk>=0 ),
   Hoehe_Segmentanfang_Stuetzbw
      REAL, -- Meter
   CHECK ( Hoehe_Segmentanfang_Stuetzbw>=0 ),
   Hoehe_Segmentende_Stuetzbw
      REAL, -- Meter
   CHECK ( Hoehe_Segmentende_Stuetzbw>=0 ),
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Pruefanweisungen (
   Pruefanweisungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   abweichende_Pruefpflicht
      VARCHAR(15),
   Pruefanweisungen
      VARCHAR(255),
   Tauchereinsatz
      VARCHAR(15),
   Pruefung_elektr_Einrichtungen
      VARCHAR(15),
   Pruefung_maschn_Einrichtungen
      VARCHAR(15),
   Bemerkungen_zur_Pruefanweisung
      VARCHAR(255)
)

CREATE TABLE durchgef_Pruefungen_Messungen (
   durchgef_Pruefungen_Messungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Pruefung
      VARCHAR(80),
   Pruefungs_Messungsdatum
      CHAR(10), -- Datum
   CHECK ( Pruefungs_Messungsdatum LIKE '__.__.____' ),
   Pruefungs_Messungszyklus
      INTEGER,
   Zustandsnote
      FLOAT (3),
   Bemerkungen_zur_durchgef_Prfg
      VARCHAR(255)
)

CREATE TABLE gegenw_dokum_Schadensstand (
   gegenw_dokum_Schadensstand_ID
      INTEGER NOT NULL PRIMARY KEY,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      FLOAT (7),
   Ortsbestimmungen_Ueberbau
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      INTEGER,
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      INTEGER,
   Schadensbewertung
      VARCHAR(15),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkungen_Schluessel
      VARCHAR(15),
   Bemerkungen_Text
      VARCHAR(255),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15)
)

CREATE TABLE gegenw_dokum_Pruefungsstand (
   gegenw_dokum_Pruefungsstand_ID
      INTEGER NOT NULL PRIMARY KEY,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      FLOAT (7),
   Ortsbestimmungen_Ueberbau
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      INTEGER,
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      INTEGER,
   Schadensbewertung
      VARCHAR(15),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkungen_Schluessel
      VARCHAR(15),
   Bemerkungen_Text
      VARCHAR(255),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15)
)

CREATE TABLE Schadensdaten_abgeschl_Prfg (
   Schadensdaten_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      FLOAT (7),
   Ortsbestimmungen_Ueberbau
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      INTEGER,
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      INTEGER,
   Schadensbewertung
      VARCHAR(15),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkungen_Schluessel
      VARCHAR(15),
   Bemerkungen_Text
      VARCHAR(255),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15)
)

CREATE TABLE Pruefungsdaten_abgeschl_Prfg (
   Pruefungsdaten_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Menge_allgemein
      VARCHAR(15),
   Menge_mit_Dimension_Schluessel
      VARCHAR(15),
   Menge_mit_Dimension
      FLOAT (7),
   Ortsbestimmungen_Ueberbau
      VARCHAR(15),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(15),
   Ortsbestimmung_Ueberbau
      VARCHAR(15),
   Ortsbest_laengs_Schluessel
      VARCHAR(15),
   Ortsbestimmung_laengs_Werte
      INTEGER,
   Ortsbestimmung_quer
      VARCHAR(15),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(15),
   Ortsbestimmung_hoch_Werte
      INTEGER,
   Schadensbewertung
      VARCHAR(15),
   Schadensveraenderungen
      VARCHAR(15),
   Bemerkungen_Schluessel
      VARCHAR(15),
   Bemerkungen_Text
      VARCHAR(255),
   Hauptbauteil
      VARCHAR(15),
   Konstruktionsteil
      VARCHAR(15),
   Bauteilergaenzung
      VARCHAR(15),
   Schaden
      VARCHAR(15)
)

CREATE TABLE Prueffahrzeuge_Pruefgeraete (
   Prueffahrzeuge_Pruefgeraete_ID
      INTEGER NOT NULL PRIMARY KEY,
   Geraeteart
      VARCHAR(15),
   voraussichtl_Einsatzdauer
      INTEGER, -- Tage
   CHECK ( voraussichtl_Einsatzdauer>=0 ),
   Bemerkungen_zu_Prueffahrzeugen
      VARCHAR(255)
)

CREATE TABLE Anlagen_Bauwerksbuch (
   Anlagen_Bauwerksbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   Beschreibung_sonst_Anlagen
      VARCHAR(255)
)

CREATE TABLE Verwaltungsmassn_Sondervereinb (
   Verwaltungsmassn_Sondervereinb_ID
      INTEGER NOT NULL PRIMARY KEY,
   Aktenzeichen_des_Verw_Akt
      VARCHAR(30),
   Veranlasser
      VARCHAR(80),
   Wirksamkeitsdatum
      CHAR(10), -- Datum
   CHECK ( Wirksamkeitsdatum LIKE '__.__.____' ),
   Beschreibung_der_Massnahme
      VARCHAR(255)
)

CREATE TABLE Verwmassn_Sonderv__von_Teilbw (
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bau_und_Erhaltungsmassnahme (
   Bau_und_Erhaltungsmassnahme_ID
      INTEGER NOT NULL PRIMARY KEY,
   Baumassnahmennummer
      VARCHAR(80),
   Bezeichnung_der_Baumassnahme
      VARCHAR(80),
   Jahr_der_Inbetriebnahme
      INTEGER, -- Jahr
   CHECK ( ( Jahr_der_Inbetriebnahme >= 1900 ) AND ( Jahr_der_Inbetriebnahme <= 2099 ) ),
   Auftragssumme
      REAL, -- DM
   CHECK ( Auftragssumme>=0 ),
   Abrechnungssumme
      REAL, -- DM
   CHECK ( Abrechnungssumme>=0 ),
   Auftraggeber_Bau_Erh_Massn
      VARCHAR(80),
   Auftragnehmer_Bau_Erh_Massn
      VARCHAR(80),
   Bauueberwachung
      VARCHAR(80),
   Baubeginn_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Baubeginn_Bau_Erh_Massn LIKE '__.__.____' ),
   Bauende_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Bauende_Bau_Erh_Massn LIKE '__.__.____' ),
   Ablauf_Gewaehrleistung
      CHAR(10), -- Datum
   CHECK ( Ablauf_Gewaehrleistung LIKE '__.__.____' ),
   Bemerkungen_Bau_Erh_Massn
      VARCHAR(255)
)

CREATE TABLE Bau_und_Erhmassn__von_Teilbw (
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bau_u_Erhaltmassn__hat_Kosten (
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme,
   Kosten_fuer_Bau_Erh_und_Betr
      INTEGER NOT NULL REFERENCES Kosten_fuer_Bau_Erh_und_Betr
)

CREATE TABLE Kosten_fuer_Bau_Erh_und_Betr (
   Kosten_fuer_Bau_Erh_und_Betr_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kostenart_Bau_Erh_Kosten
      VARCHAR(10),
   Menge_Bau_Erh_Kosten
      FLOAT (12),
   Haushaltsjahr_Bau_Erh_Kosten
      INTEGER, -- Jahr
   CHECK ( ( Haushaltsjahr_Bau_Erh_Kosten >= 1900 ) AND ( Haushaltsjahr_Bau_Erh_Kosten <= 2099 ) ),
   Kostentraeger_Bau_Erh_Kosten
      VARCHAR(120),
   Titel_Bau_Erh_Kosten
      VARCHAR(20),
   Ausgabe_Bau_Erh_Kosten
      REAL, -- DM
   CHECK ( Ausgabe_Bau_Erh_Kosten>=0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Ausstattung (
   Ausstattung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art
      VARCHAR(10),
   Einbauort
      VARCHAR(255),
   TUEV_Datum
      CHAR(10), -- Datum
   CHECK ( TUEV_Datum LIKE '__.__.____' ),
   Bemerkungen_zu_Ausstattungen
      VARCHAR(255)
)

CREATE TABLE Schutzeinrichtungen (
   Schutzeinrichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Schutzeinrichtung
      VARCHAR(15),
   Einbauort_Schutzeinrichtung
      VARCHAR(255),
   Einbaujahr_Schutzeinrichtung
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Schutzeinrichtung >= 1900 ) AND ( Einbaujahr_Schutzeinrichtung <= 2099 ) ),
   Laenge_Schutzeinrichtung
      REAL, -- Meter
   CHECK ( Laenge_Schutzeinrichtung>=0 ),
   Hoehe_Schutzeinrichtung
      REAL, -- Meter
   CHECK ( Hoehe_Schutzeinrichtung>=0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Vorspannungen (
   Vorspannungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Richtung
      VARCHAR(15),
   intern_extern
      VARCHAR(15),
   Vorspannungsgrad
      VARCHAR(15),
   Spannverfahren
      VARCHAR(15),
   Spannkraft
      REAL, -- Kilonewton
   CHECK ( Spannkraft>=0 ),
   Spannstahl_Streckgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Streckgrenze>=0 ),
   Spannstahl_Bruchgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Bruchgrenze>=0 ),
   Hersteller
      VARCHAR(15),
   Art_der_Verpressung
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbaujahr_Vorspannung
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Vorspannung >= 1900 ) AND ( Einbaujahr_Vorspannung <= 2099 ) ),
   Einbauort_Vorspannung
      VARCHAR(255),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Gruendungen (
   Gruendungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Gruendungen
      VARCHAR(15),
   Typenbezeichnung_Gruendung
      VARCHAR(80),
   Einbauort_Gruendung
      VARCHAR(255),
   Einbaujahr_Gruendung
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Gruendung >= 1900 ) AND ( Einbaujahr_Gruendung <= 2099 ) ),
   Bemerkungen_zur_Gruendung
      VARCHAR(255)
)

CREATE TABLE Erd_und_Felsanker (
   Erd_und_Felsanker_ID
      INTEGER NOT NULL PRIMARY KEY,
   Verfahren_Erd_und_Felsanker
      VARCHAR(15),
   Hersteller_Erd_und_Felsanker
      VARCHAR(15),
   Zulassungsnummer
      VARCHAR(50),
   Anzahl_Erd_und_Felsanker
      INTEGER,
   Art_Erd_und_Felsanker
      VARCHAR(255),
   Typenbez_Erd_und_Felsanker
      VARCHAR(80),
   Einbauort_Erd_und_Felsanker
      VARCHAR(255),
   Einbaujahr_Erd_und_Felsanker
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Erd_und_Felsanker >= 1900 ) AND ( Einbaujahr_Erd_und_Felsanker <= 2099 ) ),
   Bemerkungen_Erd_und_Felsanker
      VARCHAR(255)
)

CREATE TABLE Lager (
   Lager_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anzahl_der_Lager
      INTEGER,
   Art_der_Lager
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbauort_der_Lager
      VARCHAR(255),
   Einbaujahr_der_Lager
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_der_Lager >= 1900 ) AND ( Einbaujahr_der_Lager <= 2099 ) ),
   Hersteller
      VARCHAR(15),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Fahrbahnuebergangskonstruktion (
   Fahrbahnuebergangskonstruktion_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Fahrbahnuebergang
      VARCHAR(15),
   Anzahl_Fahrbahnuebergaenge
      INTEGER,
   Anzahl_der_Lamellen
      INTEGER,
   Gesamtdehnweg
      REAL, -- Millimeter
   CHECK ( Gesamtdehnweg>=0 ),
   Hersteller_Fahrbahnuebergaenge
      VARCHAR(15),
   Typenbez_Fahrbahnuebergaenge
      VARCHAR(80),
   regelgepr_Fahrbahnuebergaenge
      VARCHAR(15),
   Einbauort_Fahrbahnuebergaenge
      VARCHAR(255),
   Einbaujahr_Fahrbahnuebergaenge
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Fahrbahnuebergaenge >= 1900 ) AND ( Einbaujahr_Fahrbahnuebergaenge <= 2099 ) ),
   Konstruktionslaenge_Uebergang
      REAL, -- Meter
   CHECK ( Konstruktionslaenge_Uebergang>=0 ),
   Wartungsg_Fahrbahnuebergaenge
      VARCHAR(15),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Kappe (
   Kappe_ID
      INTEGER NOT NULL PRIMARY KEY,
   Einbauort_Kappe
      VARCHAR(255),
   Konstruktion_Kappe
      VARCHAR(15),
   Verankerung_Kappe
      VARCHAR(15),
   Ankerabstand
      REAL, -- Meter
   CHECK ( Ankerabstand>=0 ),
   groesste_Blocklaenge
      REAL, -- Meter
   CHECK ( groesste_Blocklaenge>=0 ),
   Breite_Kappe
      REAL, -- Meter
   CHECK ( Breite_Kappe>=0 ),
   Einbaujahr_Kappe
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Kappe >= 1900 ) AND ( Einbaujahr_Kappe <= 2099 ) ),
   Bemerkungen_zur_Kappe
      VARCHAR(255)
)

CREATE TABLE Brueckenseile_und_kabel (
   Brueckenseile_und_kabel_ID
      INTEGER NOT NULL PRIMARY KEY,
   Seilart
      VARCHAR(15),
   Hersteller
      VARCHAR(15),
   Tragfunktion
      VARCHAR(15),
   Seillaenge
      REAL, -- Meter
   CHECK ( Seillaenge>=0 ),
   Seildurchmesser
      REAL, -- Millimeter
   CHECK ( Seildurchmesser>=0 ),
   Seilquerschnitt_metallisch
      REAL, -- Quadratmillimeter
   CHECK ( Seilquerschnitt_metallisch>=0 ),
   Drahtfestigkeit
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Drahtfestigkeit>=0 ),
   Seilkraft
      REAL, -- Kilonewton
   CHECK ( Seilkraft>=0 ),
   Verformungsmodul
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Verformungsmodul>=0 ),
   Schlaglaenge
      REAL, -- Millimeter
   CHECK ( Schlaglaenge>=0 ),
   Gesamtgewicht
      REAL, -- Tonnen
   CHECK ( Gesamtgewicht>=0 ),
   Seilverfuellmittel
      VARCHAR(15),
   Seilaufbau
      VARCHAR(15),
   Oberflaechenbeh_des_Drahtes
      VARCHAR(15),
   Oberflaechenbeh_Seilaufbau
      VARCHAR(15),
   Vergusshuelse_Seilkopf
      VARCHAR(15),
   Werkstoff_Vergusshuelse
      VARCHAR(15),
   Seilverguss
      VARCHAR(15),
   Armaturen
      VARCHAR(15),
   schwingungsdaempf_Massnahmen
      VARCHAR(15),
   Bemerkungen_zu_Brueckenseile
      VARCHAR(255)
)

CREATE TABLE Abdichtungen (
   Abdichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Einbauort_Abdichtungen
      VARCHAR(255),
   Unterlage
      VARCHAR(15),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Behandlung_der_Unterlage
      VARCHAR(15),
   Abdichtung
      VARCHAR(15),
   Schutzschicht
      VARCHAR(15),
   Dicke_Schutzschicht
      REAL, -- Zentimeter
   CHECK ( Dicke_Schutzschicht>=0 ),
   Einbaujahr_Abdichtungen
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Abdichtungen >= 1900 ) AND ( Einbaujahr_Abdichtungen <= 2099 ) ),
   Flaeche_Abdichtungen
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Abdichtungen>=0 ),
   Hersteller_Abdichtungen
      VARCHAR(80),
   Ausfuehr_Firma_Abdichtungen
      VARCHAR(80),
   Bemerkungen_zu_Abdichtungen
      VARCHAR(255)
)

CREATE TABLE statisches_System_Tragfaehigkt (
   statisches_System_Tragfaehigkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   stat_System_in_Bauwerksachse
      VARCHAR(15),
   stat_System_quer_zu_Bauw_achse
      VARCHAR(15),
   Sonderabtragungsrichtung
      VARCHAR(15),
   Ersatzstuetzweite
      FLOAT (7),
   Tragfaehigkeit
      VARCHAR(15),
   Bemessungsfahrzeug_Hauptspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Hauptspur>=0 ),
   Bemessungsfahrzeug_Nebenspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Nebenspur>=0 ),
   statischer_Auslastungsgrad
      REAL, -- Prozent
   Bemessungslast
      REAL, -- Kilonewton
   CHECK ( Bemessungslast>=0 ),
   Einstufungsjahr
      INTEGER, -- Jahr
   CHECK ( ( Einstufungsjahr >= 1900 ) AND ( Einstufungsjahr <= 2099 ) ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Hauptbaustoff_Beton (
   Hauptbaustoff_Beton_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hauptbaustoff
      VARCHAR(15),
   Zement
      VARCHAR(15),
   Zuschlagstoff
      VARCHAR(255),
   Betonzusatz
      VARCHAR(255),
   Betondruckfestigkeit
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Betondruckfestigkeit>=0 ),
   Oberflaeche_Hauptbaust_Beton
      VARCHAR(15),
   Betonstahlguete
      VARCHAR(15),
   Fertigteile
      VARCHAR(15),
   Lieferfirma_Hauptbaust_Beton
      VARCHAR(80),
   Bemerkungen_Hauptbaust_Beton
      VARCHAR(255)
)

CREATE TABLE Hauptbaustoff_Stahl_Holz_Kunst (
   Hauptbaustoff_Stahl_Holz_Kunst_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hauptbaustoff_Stahl
      VARCHAR(80),
   Konstruktionsstahlguete
      VARCHAR(80),
   Verbindungsmittel_zum_Stahl
      VARCHAR(80),
   Lieferfirma_Stahl
      VARCHAR(80),
   Bemerkungen_zum_Stahl
      VARCHAR(255)
)

CREATE TABLE Hauptbst_SHK__hat_Korrosschutz (
   Hauptbaustoff_Stahl_Holz_Kunst
      INTEGER NOT NULL REFERENCES Hauptbaustoff_Stahl_Holz_Kunst,
   Korrosionsschutzbeschichtungen
      INTEGER NOT NULL REFERENCES Korrosionsschutzbeschichtungen
)

CREATE TABLE Hauptbaustoff_Verbundwerkst (
   Hauptbaustoff_Verbundwerkst_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hauptbaustoff_Verbundwerkst
      VARCHAR(15),
   Verbindungsmittel
      VARCHAR(15),
   Lieferfirma_Verbundwerkstoff
      VARCHAR(80),
   Bemerkungen_zum_Verbundwerkst
      VARCHAR(255)
)

CREATE TABLE Gestaltungen (
   Gestaltungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Gestaltung
      VARCHAR(255),
   Einbauort_Gestaltung
      VARCHAR(255),
   Bemerkungen_zur_Gestaltung
      VARCHAR(255)
)

CREATE TABLE Leitungen_an_Bauwerken (
   Leitungen_an_Bauwerken_ID
      INTEGER NOT NULL PRIMARY KEY,
   Leitungsarten_an_Bauwerken
      VARCHAR(15),
   Einbauort_Leitungen
      VARCHAR(255),
   Durchmesser
      REAL, -- Millimeter
   CHECK ( Durchmesser>=0 ),
   Betreiber_der_Leitung
      VARCHAR(255),
   Buendelung
      VARCHAR(15),
   Anzahl_der_Leitungen_an_Bw
      INTEGER,
   Nutzungsvereinbarung
      VARCHAR(15),
   Bemerkungen_zu_Leitungen_an_Bw
      VARCHAR(255)
)

CREATE TABLE Verfuellungen (
   Verfuellungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Einbauort_Verfuellung
      VARCHAR(255),
   Schaden_Schadenursache
      VARCHAR(255),
   Fuellgut_Fuellmaterial
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Einbaujahr_Verfuellung
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Verfuellung >= 1900 ) AND ( Einbaujahr_Verfuellung <= 2099 ) ),
   Ausfuehrende_Firma_Verfuellung
      VARCHAR(80),
   Bemerkungen_zur_Verfuellung
      VARCHAR(255)
)

CREATE TABLE Betonersatz_nach_ZTV_SIB (
   Betonersatz_nach_ZTV_SIB_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_des_Betonersatzsystems
      VARCHAR(15),
   Einbauort_Betonersatzsystem
      VARCHAR(255),
   Lieferfirma_Produktbezeichnung
      VARCHAR(15),
   Ausfuehrende_Firma_Betonersatz
      VARCHAR(80),
   Bezeichnung_zum_Betonersatz
      VARCHAR(80),
   Einbaujahr_Betonersatzsystem
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Betonersatzsystem >= 1900 ) AND ( Einbaujahr_Betonersatzsystem <= 2099 ) ),
   Flaeche_Betonersatzsystem
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Betonersatzsystem>=0 ),
   Bemerkungen_zum_Betonersatz
      VARCHAR(255)
)

CREATE TABLE Oberflschutz_nach_ZTV_SIB (
   Oberflschutz_nach_ZTV_SIB_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_des_Systems
      VARCHAR(15),
   Art_der_schuetzenden_Oberfl
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Bezeichnung
      VARCHAR(80),
   Einbauort
      VARCHAR(255),
   Verbrauch
      REAL, -- Kilogramm_pro_Quadratmeter
   CHECK ( Verbrauch>=0 ),
   Ausfuehrende_Firma
      VARCHAR(80),
   Einbaujahr
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr >= 1900 ) AND ( Einbaujahr <= 2099 ) ),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche>=0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Korrosionsschutzbeschichtungen (
   Korrosionsschutzbeschichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bauteiloberflaeche
      VARCHAR(15),
   Oberflaechenvorbereitung
      VARCHAR(15),
   Hauptbindemittel_d_Grundbesch
      VARCHAR(15),
   Hauptpigment_der_Grundbesch
      VARCHAR(15),
   Hauptbindemittel_der_Deckbesch
      VARCHAR(15),
   Hauptpigment_der_Deckbesch
      VARCHAR(15),
   Anzahl_der_Grundbeschichtungen
      INTEGER,
   Anzahl_der_Deckbeschichtungen
      INTEGER,
   Gesamtschichtdicke
      REAL, -- Mikrometer
   CHECK ( Gesamtschichtdicke>=0 ),
   Applikation
      VARCHAR(15),
   Einbauort_Schutzbeschichtung
      VARCHAR(255),
   Dichtstoffe_fuer_Fugen_o_ae
      VARCHAR(15),
   Injizierstoffe
      VARCHAR(15),
   Ausfuehrende_Firma_Besch
      VARCHAR(80),
   Bezeichnung_Schutzbeschichtung
      VARCHAR(80),
   Einbaujahr_Korrosionsschutzb
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr_Korrosionsschutzb >= 1900 ) AND ( Einbaujahr_Korrosionsschutzb <= 2099 ) ),
   Beschichtete_Flaeche
      REAL, -- Quadratmeter
   CHECK ( Beschichtete_Flaeche>=0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Reaktionsharzgeb_Duennbelaege (
   Reaktionsharzgeb_Duennbelaege_ID
      INTEGER NOT NULL PRIMARY KEY,
   Einbauort
      VARCHAR(255),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Bindemittel_der_Grundierung
      VARCHAR(15),
   Bindemittel_1_u_2_Deckschicht
      VARCHAR(15),
   Abstreumittel_ob_Deckschicht
      VARCHAR(15),
   Gesamtdicke
      REAL, -- Millimeter
   CHECK ( Gesamtdicke>=0 ),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche>=0 ),
   Einbaujahr
      INTEGER, -- Jahr
   CHECK ( ( Einbaujahr >= 1900 ) AND ( Einbaujahr <= 2099 ) ),
   Ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Tunnelbeleuchtung (
   Tunnelbeleuchtung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Lichtraster
      VARCHAR(15),
   Leuchtdichte
      INTEGER, -- cd_pro_Quadratmeter
   CHECK ( Leuchtdichte>=0 ),
   Beleuchtungsstaerke
      INTEGER, -- Lux
   CHECK ( Beleuchtungsstaerke>=0 ),
   Beleuchtungsart
      VARCHAR(15),
   Lampenart
      VARCHAR(15),
   Bemerkungen_zur_Tunnelbeleucht
      VARCHAR(255)
)

CREATE TABLE Tunnellueftung (
   Tunnellueftung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Tunnellueftung
      VARCHAR(15),
   Abluftkanaele
      VARCHAR(15),
   Zuluftkanaele
      VARCHAR(15),
   Abluftkamin
      VARCHAR(15),
   Luefterdecke
      VARCHAR(15),
   Bemerkungen_zur_Tunnellueftung
      VARCHAR(255)
)

CREATE TABLE Tunnelsicherheit (
   Tunnelsicherheit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Gefahrengueter_zugelassen
      VARCHAR(15),
   Pannenbucht
      VARCHAR(15),
   Wendebucht
      VARCHAR(15),
   Ueberfahrt
      VARCHAR(15),
   Notrufstation
      VARCHAR(15),
   Automatische_Brandmeldeanlagen
      VARCHAR(15),
   Hydranten
      VARCHAR(15),
   Fluchtwege_Querstollen
      VARCHAR(15),
   Fluchtwege_Fluchtstollen
      VARCHAR(15),
   Fernsehen
      VARCHAR(15),
   Funk
      VARCHAR(15),
   Bemerkungen_zur_Tunnelsicherh
      VARCHAR(255)
)

CREATE TABLE Tunnel_Verkehrseinrichtungen (
   Tunnel_Verkehrseinrichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Verkehrseinrichtung_vorhanden
      VARCHAR(15),
   Verkehrserfassung
      VARCHAR(15),
   LZA_vor_dem_Tunnel
      VARCHAR(15),
   Wechselverk_Zeich_v_d_Tunnel
      VARCHAR(15),
   Wechselverk_Zeichen_im_Tunnel
      VARCHAR(15),
   Fahrstreifensignale
      VARCHAR(15),
   Bemerkungen_zu_Verkehrseinr
      VARCHAR(255)
)

CREATE TABLE Tunnel_Zentrale_Anlagen (
   Tunnel_Zentrale_Anlagen_ID
      INTEGER NOT NULL PRIMARY KEY,
   gesamte_elektrische_Leistung
      INTEGER, -- Kilowatt
   CHECK ( gesamte_elektrische_Leistung>=0 ),
   Ersatzstromversorgung
      VARCHAR(15),
   Ersatzstromversorgung_Leistung
      INTEGER, -- Kilowatt
   CHECK ( Ersatzstromversorgung_Leistung>=0 ),
   Betriebsgebaeude
      VARCHAR(15),
   Betriebsgebaeude_Anzahl
      INTEGER,
   Lueftergebaeude
      VARCHAR(15),
   Lueftergebaeude_Anzahl
      INTEGER,
   Hebeanlage
      VARCHAR(15),
   Bemerkungen_zu_zentr_Anlagen
      VARCHAR(255)
)


